@@ -1,7 +1,14 @@
-from beancount.core import data, realization
-from bdantic.models.file import Entries, BeancountFile
+"""Provides functions for parsing and exporting beancont types/models.
+
+These functions are stricly helper functions in that parsing/exporting can be
+done directly by importing the appropriate model and accessing its parse/export
+method. However, most of these functions take any supported type/model as an
+input which results in less imports in your code.
+"""
+
+from beancount.core import data
+from bdantic.models.file import Directives, BeancountFile
 from bdantic.models.query import QueryResult
-from bdantic.models.realize import RealAccount
 from bdantic.types import type_map
 from bdantic.types import BeancountType, Model
 from typing import Any, Dict, List, Sequence, Tuple, Type
@@ -58,7 +65,7 @@ def parse_all(
     return [parse(obj) for obj in objs]
 
 
-def parse_entries(entries: List[data.Directive]) -> Entries:
+def parse_directives(entries: List[data.Directive]) -> Directives:
     """Parses a list of directives into a Directives model.
 
     Args:
@@ -67,7 +74,7 @@ def parse_entries(entries: List[data.Directive]) -> Entries:
     Returns:
         A Directives instance
     """
-    return Entries.parse(entries)
+    return Directives.parse(entries)
 
 
 def parse_loader(
@@ -83,7 +90,7 @@ def parse_loader(
     Returns:
         A BeancountFile model
     """
-    return BeancountFile.parse(entries, errors, options)
+    return BeancountFile.parse((entries, errors, options))
 
 
 def parse_query(
@@ -98,15 +105,3 @@ def parse_query(
         A QueryResult model
     """
     return QueryResult.parse(query_result)
-
-
-def parse_realize(real_acct: realization.RealAccount) -> RealAccount:
-    """Parses the response from running realize() on a list of entries.
-
-    Args:
-        real_acct: The realization.RealAccount to parse
-
-    Returns:
-        A RealAccount model
-    """
-    return RealAccount.parse(real_acct)
